/**
 *  文件上传组件
 *  fileType: 必传属性, 表明上传位置
 *  自定义事件 uploadFile 触发时返回上传后的文件数组
 */
var uploadFile = {
    props: ['fileType'],
    data: function () {
        return {
            files: [], //选择的图片
            uploadFiles: [], // 上传后的数据
            // fileType: 'xxjzbZdcs', // 上传地址类型
        };
    },
    methods: {
        imageError: function (event, val) {
            var path = val.path;
            if(path.indexOf('.mp4') != -1){
                path = '../../video.jpg';
            }
            var $el = $(event.target);
            event.target.src = path;
            event.onerror = null;
        },
        selectFile: function () {
            var _this = this;
            //storage
            //camera
            apiModelStore.permissions("storage").HasPermission(function (ret) {
                if (ret) {
                    apiModelStore.apiActionSheet('uploadFile', '附件添加', ['拍照', '拍视频', '手机相册'], function (ret, err) {
                        if ("1" == ret.buttonIndex) {
                            //拍照
                            apiModelStore.apiGetPicture('pic', function (ret, err) {
                                setTimeout(function () {
                                    console.log("拍照========" + JSON.stringify(ret));
                                }, 500)
                                if(!ret.data){
                                    return;
                                }
                                _this.files = [];
                                _this.uploadFiles = [];
                                _this.files = _this.checkedData([ret]);
                            })
                        } else if ("2" == ret.buttonIndex) {
                            //拍照
                            apiModelStore.apiGetPicture('video', function (ret, err) {
                                setTimeout(function () {
                                    console.log("拍照========" + JSON.stringify(ret));
                                }, 500)
                                if(!ret.data){
                                    return;
                                }
                                _this.files = [];
                                _this.uploadFiles = [];
                                _this.files = _this.checkedData([ret]);
                            })
                        } else {
                            UIAlbumBrowser.open({
                                type: 'all',
                                max: 9,
                                styles: {
                                    bg: '#fff',
                                    mark: {
                                        icon: '',
                                        position: 'bottom_left',
                                        size: 20
                                    },
                                    nav: {
                                        bg: 'rgba(0,0,0,0.6)',
                                        titleColor: '#fff',
                                        titleSize: 18,
                                        cancelColor: '#fff',
                                        cancelSize: 16,
                                        finishColor: '#fff',
                                        finishSize: 16
                                    }
                                },
                                rotation: true
                            }, function (ret) {
                                if (ret.eventType == 'confirm') { // 点击确定后
                                    _this.files = [];
                                    _this.uploadFiles = [];
                                    _this.files = ret.list;
                                    setTimeout(function () {
                                        console.log(JSON.stringify(_this.files));
                                    }, 1000)
                                }
                            });
                        }
                    })
                    // upUserImage()
                } else {
                    apiModelStore.apiToast("未获得权限")
                }

            });
        },
        checkedData: function(data){
            var arr = [];
            $.each(data, function(i, val){
                var obj = {
                    path: val.path || val.data,
                    thumbPath: val.thumbPath || val.data,
                    size: val.size || '',
                }
                if(obj.thumbPath.indexOf('.mp4') != -1){
                    obj.thumbPath = '../../image/video.jpg';
                }
                arr.push(obj)
            })
            return arr;
        },
        // 上传文件
        upload: function () {
            var _this = this;
            apiModelStore.fnKeyFrame();
            if (!this.fileType) {
                apiModelStore.fnCloseKeyFrame();
                console.log('缺少条件fileType, 无法上传');
                return;
            }
            var par = {
                files: {
                    files: (function (files) {
                        var pathArr = [];
                        $.each(files, function (i, f) {
                            pathArr.push(f.path);
                        });
                        return pathArr;
                    })(this.files)
                },
                values: {
                    fileType: this.fileType,
                    token: newUser.getToken() || ''
                }
            };
            api.ajax({
                url: kit.UPLOAD_URI,
                method: 'post',
                dataType: 'json',
                timeout: global.timeout,
                data: par,
            }, function (ret, err) {
                if (ret && ret.length > 0) {
                    _this.uploadFiles = ret;
                    console.log(JSON.stringify(ret));
                    _this.$emit('upload_file_event', ret);
                    apiModelStore.fnCloseKeyFrame();
                    apiModelStore.apiToast("文件上传成功！");
                } else {
                    apiModelStore.fnCloseKeyFrame();
                    apiModelStore.apiToast("文件上传失败！");
                }
            });


        },
        // 文件名称
        FileName: function (path) {
            var arr = path.split('/');
            return arr[arr.length - 1];
        },
        // 文件大小
        FormatSize: function (size, pointLength, units) {
            if (!size) {
                return '未知大小';
            }
            var unit;
            units = units || ['B', 'K', 'M', 'G', 'TB'];
            while ((unit = units.shift()) && size > 1024) {
                size = size / 1024;
            }
            return (unit === 'B' ? size : size.toFixed(pointLength === undefined ? 2 : pointLength)) + unit;
        },
        // 删除图片
        removeImg: function (index) {
            this.files.splice(index, 1);
        },
        showFile: function(url){
            kit.showFile(url);
        }
    },
    template: [
        '<div class="file_up_box">',
        '    <div class="file_up_header">',
        '        <div class="file_up_title title_colorBlock">',
        '            附件上传',
        '        </div>',
        '        <div class="file_up_btn">',
        '            <div class="aui-btn aui-btn-info" @click="selectFile">',
        '                {{ files.length > 0 || uploadFiles.length > 0 ? "重新选择" : "选择附件" }}',
        '            </div>',
        '            <div v-if="files.length > 0" class="aui-btn aui-btn-info" @click="upload">开始上传</div>',
        '        </div>',
        '    </div>',
        '    <div v-if="files.length > 0 || uploadFiles.length > 0" class="file_up_msg">',
        '        已{{ uploadFiles.length > 0 ? "上传":"添加" }} {{files.length || uploadFiles.length}} 个附件',
        '    </div>',
        '    <div class="file_up_body">',
        '        <!-- 上传前 -->',
        '        <div v-if="files.length > 0 && uploadFiles.length == 0" class="file_up_load_before">',
        '            <div class="file_item" v-for="(item, index) in files">',
        '                <div class="file_img">',
        '                    <img :src="item.thumbPath || item.path" alt="" @error="imageError($event, item)">',
        '                </div>',
        '                <div class="file_msg">',
        '                    <span v-text="\'文件名称：\'+ FileName(item.path || item.thumbPath)"></span>',
        '                    <span v-text="\'文件大小：\'+FormatSize(item.size)"></span>',
        '                </div>',
        '                <div class="file_remove_file">',
        '                    <i @click="removeImg(index)" class="aui-iconfont aui-icon-trash" style=" font-size: 24px"> </i>',
        '                </div>',
        '            </div>',
        '        </div>',
        '        <!-- 上传后 -->',
        '        <div v-if="uploadFiles.length > 0" class="file_up_load_after">',
        '            <div v-for="(item, index) in files">',
        '                <img :src="item.thumbPath || item.path" alt="" @error="imageError($event, item)" @click="showFile(item.path || item.thumbPath)">',
        '            </div>',
        '        </div>',
        '    </div>',
        '</div>',
    ].join(''),
};

/**
 * 流转记录组件
 * data: 必传属性, 用于展示的数据
 */
var comRecord = {
    props: ['data'],
    data: function () {
        return {};
    },
    methods: {
        details: function (id) {
            apiModelStore.apiOpenFrame("recordDetails", {}, {
                objId: id
            });
        },
        MomentFormat: function (Format, time) {
            return myMoment.momentFormat(Format, time);
        },
        //操作状态码
        operationStateCode: function (stateCode) {
            return operationStateCode(stateCode);
        },
        //事件状态码
        eventStateCode: function (stateCode) {
            return eventStateCode(stateCode);
        },
    },
    template: [
        '<div class="record_box">',
        '    <div class="record_title title_colorBlock">事项流转记录</div>',
        '    <div class="record_ul"> ',
        '        <ul>',
        '            <li>',
        '                <span>处理单位</span>',
        '                <span>处理人</span>',
        '                <span>处理时间</span>',
        '                <span>操作类型</span>',
        '                <span>处理状态</span>',
        '            </li>',
        '            <li v-if="data.length == 0"> 暂无流转记录 </li>',
        '            <li v-else v-for="itemData in data" @click="details(itemData.objId)">',
        '                <span class="aui-ellipsis-1">{{itemData.groupName?itemData.groupName:"无"}}</span>',
        '                <span>{{itemData.name}}</span>',
        '                <span v-text="itemData.clsj ? MomentFormat(\'YMD\', itemData.clsj) : \'无\' "></span>',
        '                <span v-text="eventStateCode(itemData.czlx) || \'无\'"></span>',
        '                <span v-text="operationStateCode(itemData.clzt) || \'无\'"></span>',
        '            </li>',
        '        </ul>',
        '    </div>',
        '</div>',
    ].join(''),
};