/**
 * 汉字
 * @param value
 * @param callback
 */
function validateChinese(value, callback) {
    if (value == '' || value == undefined || value == null) {
        if (callback) {
            callback(false);
        } else {
            return false;
        }

    } else {
        var reg = /^[\u4e00-\u9fa5]/;
        if (reg.test(value)) {
            if (callback) {
                callback(true);
            } else {
                return true;
            }

        } else {
            if (callback) {
                callback(false);
            } else {
                return false;
            }
        }
    }
}

/**
 * 验证短信验证码
 * @param value
 * @param callback
 */
function validateSmgCode(value, callback) {
    if (value == '' || value == undefined || value == null) {
        callback(false);
    } else {
        var reg = /^\d{4}$/;

        if ((!reg.test(value)) && value != '') {
            callback(false);
        } else {
            callback(true);
        }
    }
}


/**
 * 验证用户名
 * @param phoneNum
 * @returns {boolean}
 */
function validateUserName(value, callback) {
    if (value == '' || value == undefined || value == null) {
        callback(false);
    } else {
        var reg = /^\w+$/;
        if ((!reg.test(value)) && value != '') {
            callback(false);
        } else {
            callback(true);
        }
    }


}

/**
 * 日志
 * @param value
 * @param callback
 */
function validateJournal(value, callback) {
    if (value == '' || value == undefined || value == null) {
        callback(false);
    } else {
        var reg = /^[\u4e00-\u9fa5a-zA-Z-z0-9，,.。+-！·~、……《》（）【】：；“‘”’?？￥,\.\?:;'"\(\)]+$/;
        if (reg.test(value)) {
            callback(true);
        } else {
            callback(false);
        }
    }


}


/*是否合法IP地址*/
function validateIP(value, callback) {
    if (value == '' || value == undefined || value == null) {
        callback();
    } else {
        var reg = /^(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])\.(\d{1,2}|1\d\d|2[0-4]\d|25[0-5])$/;
        if ((!reg.test(value)) && value != '') {
            callback(new Error('请输入正确的IP地址'));
        } else {
            callback();
        }
    }
}

/* 是否手机号码或者固话*/
function validatePhoneTwo(value, callback) {
    var reg = /^((0\d{2,3}-\d{7,8})|(1[34578]\d{9}))$/;
    ;
    if (value == '' || value == undefined || value == null) {
        callback();
    } else {
        if ((!reg.test(value)) && value != '') {
            callback(new Error('请输入正确的电话号码或者固话号码'));
        } else {
            callback();
        }
    }
}


/* 是否固话*/
function validateTelphone(value, callback) {
    var reg = /0\d{2}-\d{7,8}/;
    if (value == '' || value == undefined || value == null) {
        callback();
    } else {
        if (reg.test(value)) {
            callback(new Error('请输入正确的固话（格式：区号+号码,如010-1234567）'));
        } else {
            callback();
        }
    }
}


/* 是否手机号码*/
function validatePhone(value, callback) {

    var reg = /^[1](([3][0-9])|([4][5-9])|([5][0-3,5-9])|([6][5,6])|([7][0-8])|([8][0-9])|([9][1,8,9]))[0-9]{8}$/;
    if (value == '' || value == undefined || value == null) {
        callback(false);
    } else {
        if (reg.test(value)) {
            // callback(new Error('请输入正确的电话号码'));
            callback(true);
        } else {
            callback(false);
        }
    }
}


/* 是否身份证号码*/
function validateIdNo(value, callback) {
    var reg = /(^\d{15}$)|(^\d{18}$)|(^\d{17}(\d|X|x)$)/;
    if (value == '' || value == undefined || value == null) {
        if (callback) {
            callback(false);
        } else {
            return false;
        }
    } else {
        if (reg.test(value)) {
            if (callback) {
                callback(true);
            } else {
                return true;
            }
        } else {
            if (callback) {
                callback(false);
            } else {
                return false;
            }
        }
    }
}

/* 是否邮箱*/
function validateEMail(value, callback) {
    var reg = /^([a-zA-Z0-9]+[-_\.]?)+@[a-zA-Z0-9]+\.[a-z]+$/;
    if (value == '' || value == undefined || value == null) {
        callback(false);
    } else {
        if (!reg.test(value)) {
            //callback(new Error('请输入正确的邮箱地址'));
            callback(false);
        } else {
            callback(true);
        }
    }
}

/* 合法uri*/
function validateURL(textval) {
    var urlregex = /^(https?|ftp):\/\/([a-zA-Z0-9.-]+(:[a-zA-Z0-9.&%$-]+)*@)*((25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9][0-9]?)(\.(25[0-5]|2[0-4][0-9]|1[0-9]{2}|[1-9]?[0-9])){3}|([a-zA-Z0-9-]+\.)*[a-zA-Z0-9-]+\.(com|edu|gov|int|mil|net|org|biz|arpa|info|name|pro|aero|coop|museum|[a-zA-Z]{2}))(:[0-9]+)*(\/($|[a-zA-Z0-9.,?'\\+&%$#=~_-]+))*$/;
    return urlregex.test(textval);
}

/*验证内容是否英文数字以及下划线*/
function isPassword(value, callback) {
    var reg = /^[_a-zA-Z0-9]+$/;
    if (value == '' || value == undefined || value == null) {
        callback();
    } else {
        if (!reg.test(value)) {
            callback(new Error('密码仅由英文字母，数字以及下划线组成'));
        } else {
            callback();
        }
    }
}

/*自动检验数值的范围*/
function checkMax20000(value, callback) {
    if (value == '' || value == undefined || value == null) {
        callback();
    } else if (!Number(value)) {
        callback(new Error('请输入[1,20000]之间的数字'));
    } else if (value < 1 || value > 20000) {
        callback(new Error('请输入[1,20000]之间的数字'));
    } else {
        callback();
    }
}

//验证数字输入框最大数值,32767
function checkMaxVal(value, callback) {
    if (value < 0 || value > 32767) {
        callback(new Error('请输入[0,32767]之间的数字'));
    } else {
        callback();
    }
}


/* 小写字母*/
function validateLowerCase(str) {
    var reg = /^[a-z]+$/;
    return reg.test(str);
}

/*保留2为小数*/
function validatetoFixedNew(str) {
    return str;
}

/* 验证key*/
//  function validateKey(str) {
//     var reg = /^[a-z_\-:]+$/;
//     return reg.test(str);
// }

/* 大写字母*/
function validateUpperCase(str) {
    var reg = /^[A-Z]+$/;
    return reg.test(str);
}

/* 大小写字母*/
function validatAlphabets(str) {
    var reg = /^[A-Za-z]+$/;
    return reg.test(str);
}